clear;
cd 2701_RAND_data

%read data
Y = csvread('Y.csv'); %outcome
X = csvread('X.csv'); %policy treatment
W = csvread('Wfull.csv'); %covariates

%switch signs - copay=1 means 0 transfer 
X=1-X;

[n, dimx]=size(X);
[nw, dimw]=size(W);
stdev=std(W);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%values at which to evaluate mhat, uhat, u'hat
t=(0:.01:1)';
nt=length(t);
%value of $ to the sick relative to $ for government
lambda= 1.5;
%prior parameters
%smoothness of prior: smaller = smoother; inverse of lengthscale
smootW=.2;
smoothX=1;
interceptvar=100;
slopevar=50;

%homoskedastic residual variances
sig2=1; %note this is relative to a prior variance of 1 for m
Sigma=sig2 * eye(n);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%





%%%we wil calculate covariances as product of two terms:
%one for covariates W, one for treatments X (T)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%distance squared between covariates
%year and month*location identifiers in first 2 columns of W, then
%non-categorial covariates
%distance2=zeros(n); 
distance2 = 4 * (W(:,1)*ones(1,n)~=ones(n,1)*W(:,1)').^2 ... %year identifier
          + 4 * (W(:,2)*ones(1,n)~=ones(n,1)*W(:,2)').^2; %month x location identifier
           
for j=3:dimw
    Wjnorm=W(:,j) / stdev(j);    
    distance2 = distance2 + smootW^2*(Wjnorm*ones(1,n)-ones(n,1)*Wjnorm').^2; 
end
%%  
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%cov kernel for distance 
%(note: this is without difference in policy treatments!!
CW=exp(-distance2/2);
CWbar=sum(CW)/n;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%same for policytreatment
distance2X = smoothX^2*(X*ones(1,n)-ones(n,1)*X').^2; 
CX=exp(-distance2X/2); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%delta: distance between X_i and argument value for evaluation T_j
delta = -smoothX* (X*ones(1,nt)-ones(n,1)*t')';%rows correspond to values of T
cx = normpdf(delta)/normpdf(0);
dx= (lambda /(smoothX*normpdf(0)))  * (normcdf(delta)-normcdf(-smoothX*ones(nt,1)*X')) - (t*ones(1,n)).*cx;
bx= (lambda-1 + smoothX*(t*ones(1,n)).*delta).*cx;
%now take into account sample distribution of covariate values
%as justified by noninformative Dirichlet prior
Cx= (ones(nt,1) * CWbar).* cx;
Dx= (ones(nt,1) * CWbar).* dx;
Bx= (ones(nt,1) * CWbar).* bx;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%add the "noninformative intercept & slope prior" to variance
CX=CW.*CX+interceptvar*ones(n) + slopevar * X * X';
Cx= Cx+interceptvar*ones(nt,n) + slopevar*(t*X');
Dx= Dx+interceptvar*(lambda-1)*(t*ones(1,n)) + 0.5* slopevar*(lambda-2)*((t.^2)*X');
Bx= Bx+interceptvar*(lambda-1)*ones(nt,n) + slopevar*(lambda-2)*(t*X');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculation of posterior expectations
Ytilde = (CX + Sigma) \ Y;
mhat = Cx * Ytilde;
uhat = Dx * Ytilde;
uprimehat = Bx * Ytilde;

[maxu,argmaxu]=max(uhat);
argmaxu=(argmaxu-1)/100



cprimex=-(ones(nt,1) * CWbar).*(smoothX*delta.*cx) + slopevar*(ones(nt,1)*X');
% cintx=(1 /(smoothX*normpdf(0)))  * (normcdf(delta)-normcdf(-smoothX*ones(nt,1)*X'))+interceptvar*(t*ones(1,n)); 
mprimehat=cprimex * Ytilde;
% minthat=((ones(nt,1) * CWbar).*cintx) * Ytilde;

%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculation of posterior variance of uprime
%start with given CX, Sigma, which are only relative 
%prior variance first - using c(x,x)=1 for sq exp kernel terms
varuprime = mean(CWbar)*((lambda-1)^2 * ones(nt,1) + smoothX^2 *t.^2) ... 
             + interceptvar*(lambda-1)^2* ones(nt,1) +  slopevar*(lambda-2)^2*t.^2;
%prior variance of uprimehat
varuprimehat = diag( Bx * ((CX + Sigma) \ Bx'));

posteriorvaruprime = varuprime - varuprimehat;


%now scale them up to empirical residual variance
Yhat=CX*Ytilde;
epsilon=Yhat-Y;
sig2empirical=var(epsilon);
posteriorvaruprime=posteriorvaruprime*sig2empirical/sig2;

uprimeupper=  uprimehat +    1.96*sqrt(posteriorvaruprime);
uprimelower=  uprimehat -    1.96*sqrt(posteriorvaruprime);



%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculation of frequentist confidence bands for uprime
%using the same smoothing weights CX  / (CX + Sigma) for estimation of conditional variances as
%for conditional means
sig2hat = CX  * ((CX + Sigma) \ ((Y-CX*Ytilde).^2));
frequentistvaruprimehat= (Bx/(CX+Sigma)).^2 * sig2hat;


frequentistuprimeupper=  uprimehat +    1.96*sqrt(frequentistvaruprimehat);
frequentistuprimelower=  uprimehat -    1.96*sqrt(frequentistvaruprimehat);


        
        
        
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%printing
% mhat and mprimehat
scalem=1.2*max(mhat);
set(0,'DefaultAxesColorOrder',[0 0 0], 'DefaultAxesLineStyleOrder','-|-.|-')
fig = figure('Visible','on',...
      'PaperPosition',[0 0 6 4],...
      'PaperSize',[6 4])

plot(t, mhat, 'Color',[.4 .4 .8],'LineWidth',3);
hold on
p= plot(t,mprimehat, 'Color',[.6 .6 .6],'LineWidth',3)
plot(t, zeros(nt,1), 'Color',[.8 .8 .8],'LineWidth',1);
hold off
%ylabel('$\widehat{m},\; \widehat{m}^\prime$', 'Interpreter','LaTex');
ax = gca;
ax.XTick=0:.2:1;
ax.YTick=-0:500:2000;
hleg1 = legend('$\widehat{m}$','$\widehat{m}^\prime$');
set(hleg1,'Interpreter','LaTex');
set(hleg1,'FontSize',20);
set(hleg1,'Location','SouthEast');
xlabel('$t$', 'Interpreter','LaTex');
axis([0 1 -400 2300])
%axis([0 1 -scalem scalem])
print(fig,'-dpdf','mhat.pdf')

 %%

%uhat and uprimehat
scaleu=1.5*max(uhat);
set(0,'DefaultAxesColorOrder',[0 0 0], 'DefaultAxesLineStyleOrder','-|-.|-|:')
fig = figure('Visible','on',...
      'PaperPosition',[0 0 6 4],...
      'PaperSize',[6 4])
p=plot(t, uhat, 'Color',[.4 .4 .8],'LineWidth',3);  
hold on  
plot(t, uprimehat, 'Color',[.6 .6 .6],'LineWidth',3);
plot(t, zeros(nt,1), 'Color',[.8 .8 .8],'LineWidth',1);
hold off
ax = gca;
ax.XTick=0:.2:1;
ax.YTick=-400:200:800;
%ylabel('$\widehat{u},\; \widehat{u}^\prime$', 'Interpreter','LaTex');
hleg1 = legend('$\widehat{u}$','$\widehat{u}^\prime$');
set(hleg1,'Interpreter','LaTex');
set(hleg1,'FontSize',20);
set(hleg1,'Location','SouthWest');
xlabel('$t$', 'Interpreter','LaTex');
axis([0 1 -500 900])
%axis([0 1 -scaleu scaleu])
%set(gca,'Position',[0 0 1 1])
print(fig,'-dpdf','uhat.pdf')


%%
%confidence band (or pointwise credible set) for uprime
scaleup=1.1*max(uprimeupper);
scalelow=1.1*min(uprimelower);
set(0,'DefaultAxesColorOrder',[0 0 0], 'DefaultAxesLineStyleOrder','-|--|--|-')
fig = figure('Visible','on',...
      'PaperPosition',[0 0 6 4],...
      'PaperSize',[6 4])
p=plot(t, uprimehat, 'Color',[.4 .4 .8],'LineWidth',3);
hold on 
plot(t, [uprimeupper uprimelower], 'Color',[.4 .4 .8],'LineWidth',1.5);
plot(t, zeros(nt,1), 'Color',[.8 .8 .8],'LineWidth',1 );
hold off
ax = gca;
ax.XTick=0:.2:1;
ax.YTick=-1200:200:1000;
xlabel('$t$', 'Interpreter','LaTex');
hleg1 = legend('$\widehat{u}^\prime$');
set(hleg1,'Interpreter','LaTex');
set(hleg1,'FontSize',20);
set(hleg1,'Location','SouthWest');
%ylabel('$\widehat{u}^\prime$', 'Interpreter','LaTex');
axis([0 1 scalelow scaleup])
%set(gca,'Position',[0 0 1 1])
print(fig,'-dpdf','uprimehat.pdf')

 

