clear;
cd 2701_RAND_data

%read data
Y = csvread('Y.csv'); %outcome
X = csvread('X.csv'); %policy treatment
W = csvread('Wfull.csv'); %covariates

%switch signs - copay=1 means 0 transfer 
X=1-X;


[n, dimx]=size(X);
[nw, dimw]=size(W);
stdev=std(W);


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%values at which to evaluate mhat, uhat, u'hat
t=(0:.005:1)';
nt=length(t);
%value of $ to the sick relative to $ for government
%prior parameters
%smoothness of prior: smaller = smoother; inverse of lengthscale
smootW=.2;
smoothX=1;
interceptvar=100;
slopevar=50;

%homoskedastic residual variances
sig2=1; %note this is relative to a prior variance of 1 for m
Sigma=sig2 * eye(n);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%




%%%we wil calculate covariances as product of two terms:
%one for covariates W, one for treatments X (T)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%distance squared betwee covariates
%year and month*location identifiers in first 2 columns of W, then
%non-categorial covariates
%distance2=zeros(n); 
distance2 = 4 * (W(:,1)*ones(1,n)~=ones(n,1)*W(:,1)').^2 ... %year identifier
          + 4 * (W(:,2)*ones(1,n)~=ones(n,1)*W(:,2)').^2; %month x location identifier
           
for j=3:dimw
    Wjnorm=W(:,j) / stdev(j);    
    distance2 = distance2 + smootW^2*(Wjnorm*ones(1,n)-ones(n,1)*Wjnorm').^2; 
end
%%  
%%%%%%%%%%%%%%%%%%%%%%%%%%%
%cov kernel for distance 
%(note: this is without difference in policy treatments!!
CW=exp(-distance2/2);
CWbar=sum(CW)/n;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%same for policytreatment
distance2X = smoothX^2*(X*ones(1,n)-ones(n,1)*X').^2; 
CX=exp(-distance2X/2); 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%delta: distance between X_i and argument value for evaluation T_j
delta = -smoothX* (X*ones(1,nt)-ones(n,1)*t')';%rows correspond to values of T
cx = normpdf(delta)/normpdf(0);
%now take into account sample distribution of covariate values
%as justified by noninformative Dirichlet prior
Cx= (ones(nt,1) * CWbar).* cx;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%add the "noninformative intercept & slope prior" to variance
CX=CW.*CX+interceptvar*ones(n) + slopevar * X * X';
Cx= Cx+interceptvar*ones(nt,n) + slopevar*(t*X');



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%calculation of posterior expectations
Ytilde = (CX + Sigma) \ Y;
mhat = Cx * Ytilde;



%%
steps=101;
optpolML=zeros(steps,1);
optpolSuffstatpoint2=zeros(steps,1);
optpolSuffstatpoint5=zeros(steps,1);
lambdas=zeros(steps,1);

for i=1:steps
    lambda=1+(i-1)/(steps-1);    
    
    dx= (lambda /(smoothX*normpdf(0)))  * (normcdf(delta)-normcdf(-smoothX*ones(nt,1)*X')) - (t*ones(1,n)).*cx;
    %now take into account sample distribution of covariate values
    %as justified by noninformative Dirichlet prior
    Dx= (ones(nt,1) * CWbar).* dx;
    %add the "noninformative intercept & slope prior" to variance
    Dx= Dx+interceptvar*(lambda-1)*(t*ones(1,n)) + 0.5* slopevar*(lambda-2)*((t.^2)*X');
    %calculation of posterior expectations
    uhat = Dx * Ytilde;

    [maxu,argmaxu]=max(uhat);

    optpolML(i)=(argmaxu-1)/(nt-1);
    optpolSuffstatpoint2(i)=1/(1+0.2/(lambda-1));
    optpolSuffstatpoint5(i)=1/(1+0.5/(lambda-1));
    lambdas(i)=lambda;
end


%%
 
set(0,'DefaultAxesColorOrder',[0 0 0], 'DefaultAxesLineStyleOrder','-|-.|:|-|:')
fig = figure('Visible','on',...
      'PaperPosition',[0 0 6 4],...
      'PaperSize',[6 4])
  

plot(lambdas, optpolML, 'Color',[.4 .4 .8],'LineWidth',3);
hold on
p= plot(lambdas, optpolSuffstatpoint5, 'Color',[.4 .4 .8],'LineWidth',3);
plot(lambdas, optpolSuffstatpoint2, 'Color',[.4 .4 .8],'LineWidth',3);
hold off  
ax = gca;
ax.XTick=1:.2:2;
ax.YTick=0:.2:1;
ylabel('$t^*$', 'Interpreter','LaTex');
hleg1 = legend('our method','suff stat, $\eta=.5$','suff stat, $\eta=.2$');
set(hleg1,'Interpreter','LaTex');
set(hleg1,'FontSize',20);
set(hleg1,'Location','SouthEast');
xlabel('$\lambda$', 'Interpreter','LaTex');
axis([1 2 0 1])
print(fig,'-dpdf','tstar.pdf')
